# Profile for configuring puppet-server to act as a certificate authority.
#
# Also performs some fileserver configuration to allow additional compile masters
# to get PE modules.
#
# For more information, see the [README.md](./README.md#certificate-authority)
#
# @param client_whitelist [Array] A list of additional certificates to be allowed access
#         to the /certificate_status API endpoint. This list is additive to the base PE
#         certificate list.
class puppet_enterprise::profile::certificate_authority (
  $client_whitelist = []
) inherits puppet_enterprise::profile::master {
  include puppet_enterprise::params

  pe_validate_array($client_whitelist)

  Puppet_enterprise::Trapperkeeper::Bootstrap_cfg['certificate-authority-service'] {
    namespace => 'puppetlabs.services.ca.certificate-authority-service',
    service   => 'certificate-authority-service',
    notify  => Service['pe-puppetserver'],
  }

  $console_client_certname = $puppet_enterprise::params::console_client_certname
  $_client_whitelist = pe_union([$console_client_certname], $client_whitelist)

  # Uses
  #   $_client_whitelist
  File['/etc/puppetlabs/puppetserver/conf.d/ca.conf'] {
    ensure  => file,
    content => template('puppet_enterprise/master/puppetserver/ca.conf.erb'),
    notify  => Service['pe-puppetserver'],
  }

  # FILESERVER
  # The certificate authority in a standard PE deployment is also the
  # master-of-masters responsible for deploying new systems. Besides native OS
  # packages, PE has its own "packaged" components that may need to be deployed
  # on new systems. We will serve these using Puppet's built-in fileserver.

  $fileserver = '/etc/puppetlabs/puppet/fileserver.conf'
  $tarballsrc = $puppet_enterprise::params::module_tarballsrc
  $mountpoint = $puppet_enterprise::params::module_mountpoint

  augeas { "fileserver.conf ${mountpoint}":
    changes   => [
      "set /files/${fileserver}/${mountpoint}/path ${tarballsrc}",
      "set /files/${fileserver}/${mountpoint}/allow *",
    ],
    incl      => $fileserver,
    load_path => '/opt/puppet/share/augeas/lenses/dist',
    lens      => 'PuppetFileserver.lns',
    before    => Pe_anchor['puppet_enterprise:barrier:ca']
  }
}
